import { EntityRepository, Repository } from "typeorm";
import { ContactPageCmsEntity } from "./entities/contact-page-cms.entity";
import { UpdateContactPageCmsDto } from "./dto/update-contact-page-cms.dto";

@EntityRepository(ContactPageCmsEntity)
export class ContactPageCmsRepository extends Repository<ContactPageCmsEntity> {

    async createEntity(dto: UpdateContactPageCmsDto): Promise<ContactPageCmsEntity | Error> {
        try {
            const entity = this.create({
                pageTitle: dto.pageTitle,
                pageDescription: dto.pageDescription,
                formTitle: dto.formTitle,
                formDescription: dto.formDescription,
                buttonText: dto.buttonText,
                mapUrl: dto.mapUrl,
                address: dto.address,
                contact: dto.contact,
                email: dto.email
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateContactPageCmsDto, id: string): Promise<ContactPageCmsEntity | Error> {
        try {
            await this.update(id, {
                pageTitle: dto.pageTitle,
                pageDescription: dto.pageDescription,
                formTitle: dto.formTitle,
                formDescription: dto.formDescription,
                buttonText: dto.buttonText,
                mapUrl: dto.mapUrl,
                address: dto.address,
                contact: dto.contact,
                email: dto.email
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<ContactPageCmsEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}