import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UpdateHomePageDiscoverSectionCmsDto } from "./dto/update-home-page-discover-section-cms.dto";
import { HomePageDiscoverSectionCmsEntity } from "./entities/home-page-discover-section-cms.entity";
import { HomePageDiscoverSectionCmsRepository } from "./home-page-discover-section-cms.repository";

@Injectable()
export class HomePageDiscoverSectionCmsService {
    constructor(
        @InjectRepository(HomePageDiscoverSectionCmsRepository)
        private readonly repository: HomePageDiscoverSectionCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateHomePageDiscoverSectionCmsDto,
        files: {
            imageOne: UploadedMulterFileI,
            imageTwo: UploadedMulterFileI
        }
    ): Promise<HomePageDiscoverSectionCmsEntity | Error> {
        if (files && files.imageOne) {
            const imageOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "HomePageDiscoverSectionCms/");
            dto.imageOne = imageOne;
        }
        if (files && files.imageTwo) {
            const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "HomePageDiscoverSectionCms/");
            dto.imageTwo = imageTwo;
        }
        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageDiscoverSectionCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}